Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(321)

Unified Diff: chrome/browser/autofill/personal_data_manager.h

Issue 10908065: Introduce a couple of abstract bases for WebDataService. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/personal_data_manager.h
diff --git a/chrome/browser/autofill/personal_data_manager.h b/chrome/browser/autofill/personal_data_manager.h
index 47d3ccb4cfa3386c4f8d40b0ef946e90b370ed7b..ca860b335f4debb2119d2db28d09acf416341de5 100644
--- a/chrome/browser/autofill/personal_data_manager.h
+++ b/chrome/browser/autofill/personal_data_manager.h
@@ -16,9 +16,9 @@
#include "chrome/browser/autofill/autofill_profile.h"
#include "chrome/browser/autofill/credit_card.h"
#include "chrome/browser/autofill/field_types.h"
+#include "chrome/browser/api/webdata/autofill_web_data.h"
#include "chrome/browser/profiles/profile_keyed_service.h"
#include "chrome/browser/sync/profile_sync_service_observer.h"
-#include "chrome/browser/webdata/web_data_service.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
@@ -43,7 +43,7 @@ class PersonalDataManager
public:
// WebDataServiceConsumer:
virtual void OnWebDataServiceRequestDone(
- WebDataService::Handle h,
+ WebDataServiceBase::Handle h,
const WDTypedResult* result) OVERRIDE;
// Sets the listener to be notified of PersonalDataManager events.
@@ -56,13 +56,13 @@ class PersonalDataManager
virtual void OnStateChanged() OVERRIDE;
// ProfileKeyedService:
// Cancels any pending requests to WebDataService and stops listening for Sync
// notifications.
virtual void Shutdown() OVERRIDE;
// content::NotificationObserver:
// Observes "batch" changes made by Sync and refreshes data from the
// WebDataService in response.
virtual void Observe(int type,
const content::NotificationSource& source,
const content::NotificationDetails& details) OVERRIDE;
@@ -189,17 +189,17 @@ class PersonalDataManager
// Receives the loaded profiles from the web data service and stores them in
// |credit_cards_|.
- void ReceiveLoadedProfiles(WebDataService::Handle h,
+ void ReceiveLoadedProfiles(WebDataServiceBase::Handle h,
const WDTypedResult* result);
// Receives the loaded credit cards from the web data service and stores them
// in |credit_cards_|.
- void ReceiveLoadedCreditCards(WebDataService::Handle h,
+ void ReceiveLoadedCreditCards(WebDataServiceBase::Handle h,
const WDTypedResult* result);
// Cancels a pending query to the web database. |handle| is a pointer to the
// query handle.
- void CancelPendingQuery(WebDataService::Handle* handle);
+ void CancelPendingQuery(WebDataServiceBase::Handle* handle);
// Saves |imported_profile| to the WebDB if it exists.
virtual void SaveImportedProfile(const AutofillProfile& imported_profile);
@@ -237,12 +237,12 @@ class PersonalDataManager
// The loaded credit cards.
ScopedVector<CreditCard> credit_cards_;
// When the manager makes a request from WebDataService, the database
// is queried on another thread, we record the query handle until we
// get called back. We store handles for both profile and credit card queries
// so they can be loaded at the same time.
- WebDataService::Handle pending_profiles_query_;
- WebDataService::Handle pending_creditcards_query_;
+ WebDataServiceBase::Handle pending_profiles_query_;
+ WebDataServiceBase::Handle pending_creditcards_query_;
// The observers.
ObserverList<PersonalDataManagerObserver> observers_;
@@ -56,13 +56,13 @@ class PersonalDataManager
virtual void OnStateChanged() OVERRIDE;
// ProfileKeyedService:
- // Cancels any pending requests to WebDataService and stops listening for Sync
- // notifications.
+ // Cancels any pending requests to WebDataServiceBase and stops
+ // listening for Sync notifications.
virtual void Shutdown() OVERRIDE;
// content::NotificationObserver:
@@ -56,13 +56,13 @@ class PersonalDataManager
// content::NotificationObserver:
// Observes "batch" changes made by Sync and refreshes data from the
- // WebDataService in response.
+ // WebDataServiceBase in response.
virtual void Observe(int type,
const content::NotificationSource& source,
@@ -237,12 +237,12 @@ class PersonalDataManager
// The loaded credit cards.
ScopedVector<CreditCard> credit_cards_;
- // When the manager makes a request from WebDataService, the database
+ // When the manager makes a request from WebDataServiceBase, the database
// is queried on another thread, we record the query handle until we
// get called back. We store handles for both profile and credit card queries

Powered by Google App Engine
This is Rietveld 408576698